pyxmpp2.mainloop.poll

Package pyxmpp2 :: Package mainloop :: Module poll |
[hide private]

# Module poll

I/O Handling classes

This module has a purpose similar to `asyncore` from the base library, but should be more usable, especially for PyXMPP.

Also, these interfaces should allow building application not only in asynchronous event loop model, but also threaded model.

Classes | [hide private]
| PollMainLoop Main event loop based on the poll() syscall.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.mainloop.poll")`